"""


Mesh Delimit Mode Items
^^^^^^^^^^^^^^^^^^^^^^^

:NORMAL:          
  Normal.

  Delimit by face directions.

:MATERIAL:        
  Material.

  Delimit by face material.

:SEAM:            
  Seam.

  Delimit by edge seams.

:SHARP:           
  Sharp.

  Delimit by sharp edges.

:UV:              
  UVs.

  Delimit by UV coordinates.

.. _rna-enum-mesh-delimit-mode-items:

"""

import typing
