"""


Metaelem Type Items
^^^^^^^^^^^^^^^^^^^

:BALL:            
  Ball.

:CAPSULE:         
  Capsule.

:PLANE:           
  Plane.

:ELLIPSOID:       
  Ellipsoid.

:CUBE:            
  Cube.

.. _rna-enum-metaelem-type-items:

"""

import typing
