"""


Attribute Domain Edge Face Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:EDGE:            
  Edge.

  Attribute on mesh edge.

:FACE:            
  Face.

  Attribute on mesh faces.

.. _rna-enum-attribute-domain-edge-face-items:

"""

import typing
