"""


Node Geometry Mesh Circle Fill Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:NONE:            
  None.

:NGON:            
  N-Gon.

:TRIANGLE_FAN:    
  Triangles.

.. _rna-enum-node-geometry-mesh-circle-fill-type-items:

"""

import typing
