"""


Event Type Items
^^^^^^^^^^^^^^^^

:NONE:            
:LEFTMOUSE:       
  Left Mouse.

  LMB.

:MIDDLEMOUSE:     
  Middle Mouse.

  MMB.

:RIGHTMOUSE:      
  Right Mouse.

  RMB.

:BUTTON4MOUSE:    
  Button4 Mouse.

  MB4.

:BUTTON5MOUSE:    
  Button5 Mouse.

  MB5.

:BUTTON6MOUSE:    
  Button6 Mouse.

  MB6.

:BUTTON7MOUSE:    
  Button7 Mouse.

  MB7.

.. _rna-enum-event-type-items:

======================================================================

:PEN:             
  Pen.

:ERASER:          
  Eraser.

======================================================================

:MOUSEMOVE:       
  Mouse Move.

  MsMov.

:INBETWEEN_MOUSEMOVE:
  In-between Move.

  MsSubMov.

:TRACKPADPAN:     
  Mouse/Trackpad Pan.

  MsPan.

:TRACKPADZOOM:    
  Mouse/Trackpad Zoom.

  MsZoom.

:MOUSEROTATE:     
  Mouse/Trackpad Rotate.

  MsRot.

:MOUSESMARTZOOM:  
  Mouse/Trackpad Smart Zoom.

  MsSmartZoom.

======================================================================

:WHEELUPMOUSE:    
  Wheel Up.

  WhUp.

:WHEELDOWNMOUSE:  
  Wheel Down.

  WhDown.

:WHEELINMOUSE:    
  Wheel In.

  WhIn.

:WHEELOUTMOUSE:   
  Wheel Out.

  WhOut.

======================================================================

:A:               
:B:               
:C:               
:D:               
:E:               
:F:               
:G:               
:H:               
:I:               
:J:               
:K:               
:L:               
:M:               
:N:               
:O:               
:P:               
:Q:               
:R:               
:S:               
:T:               
:U:               
:V:               
:W:               
:X:               
:Y:               
:Z:               
======================================================================

:ZERO:            
:ONE:             
:TWO:             
:THREE:           
:FOUR:            
:FIVE:            
:SIX:             
:SEVEN:           
:EIGHT:           
:NINE:            
======================================================================

:LEFT_CTRL:       
  Left Ctrl.

  CtrlL.

:LEFT_ALT:        
  Left Alt.

  AltL.

:LEFT_SHIFT:      
  Left Shift.

  ShiftL.

:RIGHT_ALT:       
  Right Alt.

  AltR.

:RIGHT_CTRL:      
  Right Ctrl.

  CtrlR.

:RIGHT_SHIFT:     
  Right Shift.

  ShiftR.

======================================================================

:OSKEY:           
  OS Key.

  Cmd.

:APP:             
  Application.

  App.

:GRLESS:          
  Grless.

:ESC:             
  Esc.

:TAB:             
  Tab.

:RET:             
  Return.

  Enter.

:SPACE:           
  Spacebar.

  Space.

:LINE_FEED:       
  Line Feed.

:BACK_SPACE:      
  Backspace.

  BkSpace.

:DEL:             
  Delete.

  Del.

:SEMI_COLON:      
  ;.

:PERIOD:          
:COMMA:           
  ,.

:QUOTE:           
  ".

:ACCENT_GRAVE:    
  `.

:MINUS:           
  -.

:PLUS:            
  +.

:SLASH:           
  /.

:BACK_SLASH:      
  \.

:EQUAL:           
  =.

:LEFT_BRACKET:    
  [.

:RIGHT_BRACKET:   
  ].

:LEFT_ARROW:      
  Left Arrow.

  ←.

:DOWN_ARROW:      
  Down Arrow.

  ↓.

:RIGHT_ARROW:     
  Right Arrow.

  →.

:UP_ARROW:        
  Up Arrow.

  ↑.

:NUMPAD_2:        
  Numpad 2.

  Pad2.

:NUMPAD_4:        
  Numpad 4.

  Pad4.

:NUMPAD_6:        
  Numpad 6.

  Pad6.

:NUMPAD_8:        
  Numpad 8.

  Pad8.

:NUMPAD_1:        
  Numpad 1.

  Pad1.

:NUMPAD_3:        
  Numpad 3.

  Pad3.

:NUMPAD_5:        
  Numpad 5.

  Pad5.

:NUMPAD_7:        
  Numpad 7.

  Pad7.

:NUMPAD_9:        
  Numpad 9.

  Pad9.

:NUMPAD_PERIOD:   
  Numpad ..

  Pad..

:NUMPAD_SLASH:    
  Numpad /.

  Pad/.

:NUMPAD_ASTERIX:  
  Numpad *.

  Pad*.

:NUMPAD_0:        
  Numpad 0.

  Pad0.

:NUMPAD_MINUS:    
  Numpad -.

  Pad-.

:NUMPAD_ENTER:    
  Numpad Enter.

  PadEnter.

:NUMPAD_PLUS:     
  Numpad +.

  Pad+.

:F1:              
  F1.

:F2:              
  F2.

:F3:              
  F3.

:F4:              
  F4.

:F5:              
  F5.

:F6:              
  F6.

:F7:              
  F7.

:F8:              
  F8.

:F9:              
  F9.

:F10:             
  F10.

:F11:             
  F11.

:F12:             
  F12.

:F13:             
  F13.

:F14:             
  F14.

:F15:             
  F15.

:F16:             
  F16.

:F17:             
  F17.

:F18:             
  F18.

:F19:             
  F19.

:F20:             
  F20.

:F21:             
  F21.

:F22:             
  F22.

:F23:             
  F23.

:F24:             
  F24.

:PAUSE:           
  Pause.

:INSERT:          
  Insert.

  Ins.

:HOME:            
  Home.

:PAGE_UP:         
  Page Up.

  PgUp.

:PAGE_DOWN:       
  Page Down.

  PgDown.

:END:             
  End.

======================================================================

:MEDIA_PLAY:      
  Media Play/Pause.

  ⏯.

:MEDIA_STOP:      
  Media Stop.

  ⏹.

:MEDIA_FIRST:     
  Media First.

  ⏮.

:MEDIA_LAST:      
  Media Last.

  ⏭.

======================================================================

:TEXTINPUT:       
  Text Input.

  TxtIn.

======================================================================

:WINDOW_DEACTIVATE:
  Window Deactivate.

:TIMER:           
  Timer.

  Tmr.

:TIMER0:          
  Timer 0.

  Tmr0.

:TIMER1:          
  Timer 1.

  Tmr1.

:TIMER2:          
  Timer 2.

  Tmr2.

:TIMER_JOBS:      
  Timer Jobs.

  TmrJob.

:TIMER_AUTOSAVE:  
  Timer Autosave.

  TmrSave.

:TIMER_REPORT:    
  Timer Report.

  TmrReport.

:TIMERREGION:     
  Timer Region.

  TmrReg.

======================================================================

:NDOF_MOTION:     
  NDOF Motion.

  NdofMov.

:NDOF_BUTTON_MENU:
  NDOF Menu.

  NdofMenu.

:NDOF_BUTTON_FIT: 
  NDOF Fit.

  NdofFit.

:NDOF_BUTTON_TOP: 
  NDOF Top.

  Ndof↑.

:NDOF_BUTTON_BOTTOM:
  NDOF Bottom.

  Ndof↓.

:NDOF_BUTTON_LEFT:
  NDOF Left.

  Ndof←.

:NDOF_BUTTON_RIGHT:
  NDOF Right.

  Ndof→.

:NDOF_BUTTON_FRONT:
  NDOF Front.

  NdofFront.

:NDOF_BUTTON_BACK:
  NDOF Back.

  NdofBack.

:NDOF_BUTTON_ISO1:
  NDOF Isometric 1.

  NdofIso1.

:NDOF_BUTTON_ISO2:
  NDOF Isometric 2.

  NdofIso2.

:NDOF_BUTTON_ROLL_CW:
  NDOF Roll CW.

  NdofRCW.

:NDOF_BUTTON_ROLL_CCW:
  NDOF Roll CCW.

  NdofRCCW.

:NDOF_BUTTON_SPIN_CW:
  NDOF Spin CW.

  NdofSCW.

:NDOF_BUTTON_SPIN_CCW:
  NDOF Spin CCW.

  NdofSCCW.

:NDOF_BUTTON_TILT_CW:
  NDOF Tilt CW.

  NdofTCW.

:NDOF_BUTTON_TILT_CCW:
  NDOF Tilt CCW.

  NdofTCCW.

:NDOF_BUTTON_ROTATE:
  NDOF Rotate.

  NdofRot.

:NDOF_BUTTON_PANZOOM:
  NDOF Pan/Zoom.

  NdofPanZoom.

:NDOF_BUTTON_DOMINANT:
  NDOF Dominant.

  NdofDom.

:NDOF_BUTTON_PLUS:
  NDOF Plus.

  Ndof+.

:NDOF_BUTTON_MINUS:
  NDOF Minus.

  Ndof-.

:NDOF_BUTTON_V1:  
  NDOF View 1.

:NDOF_BUTTON_V2:  
  NDOF View 2.

:NDOF_BUTTON_V3:  
  NDOF View 3.

:NDOF_BUTTON_1:   
  NDOF Button 1.

  NdofB1.

:NDOF_BUTTON_2:   
  NDOF Button 2.

  NdofB2.

:NDOF_BUTTON_3:   
  NDOF Button 3.

  NdofB3.

:NDOF_BUTTON_4:   
  NDOF Button 4.

  NdofB4.

:NDOF_BUTTON_5:   
  NDOF Button 5.

  NdofB5.

:NDOF_BUTTON_6:   
  NDOF Button 6.

  NdofB6.

:NDOF_BUTTON_7:   
  NDOF Button 7.

  NdofB7.

:NDOF_BUTTON_8:   
  NDOF Button 8.

  NdofB8.

:NDOF_BUTTON_9:   
  NDOF Button 9.

  NdofB9.

:NDOF_BUTTON_10:  
  NDOF Button 10.

  NdofB10.

:NDOF_BUTTON_A:   
  NDOF Button A.

  NdofBA.

:NDOF_BUTTON_B:   
  NDOF Button B.

  NdofBB.

:NDOF_BUTTON_C:   
  NDOF Button C.

  NdofBC.

:ACTIONZONE_AREA: 
  ActionZone Area.

  AZone Area.

:ACTIONZONE_REGION:
  ActionZone Region.

  AZone Region.

:ACTIONZONE_FULLSCREEN:
  ActionZone Fullscreen.

  AZone FullScr.

:XR_ACTION:       
  XR Action.

"""

import typing
