"""


Space File Browse Mode Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:FILES:           
  File Browser.

:ASSETS:          
  Asset Browser.

.. _rna-enum-space-file-browse-mode-items:

"""

import typing
