"""


Modifier Triangulate Quad Method Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:BEAUTY:          
  Beauty.

  Split the quads in nice triangles, slower method.

:FIXED:           
  Fixed.

  Split the quads on the first and third vertices.

:FIXED_ALTERNATE: 
  Fixed Alternate.

  Split the quads on the 2nd and 4th vertices.

:SHORTEST_DIAGONAL:
  Shortest Diagonal.

  Split the quads along their shortest diagonal.

:LONGEST_DIAGONAL:
  Longest Diagonal.

  Split the quads along their longest diagonal.

.. _rna-enum-modifier-triangulate-quad-method-items:

"""

import typing
