"""


Brush Gpencil Vertex Types Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:DRAW:            
  Draw.

  Paint a color on stroke points.

:BLUR:            
  Blur.

  Smooth out the colors of adjacent stroke points.

:AVERAGE:         
  Average.

  Smooth out colors with the average color under the brush.

:SMEAR:           
  Smear.

  Smudge colors by grabbing and dragging them.

:REPLACE:         
  Replace.

  Replace the color of stroke points that already have a color applied.

.. _rna-enum-brush-gpencil-vertex-types-items:

"""

import typing
