"""


Interpolation Utilities (mathutils.interpolate)
***********************************************

The Blender interpolate module

:func:`poly_3d_calc`

"""

import typing

def poly_3d_calc(veclist: typing.Any, pt: typing.Any) -> None:

  """

  Calculate barycentric weights for a point on a polygon.

  """

  ...
