"""


Context Mode Items
^^^^^^^^^^^^^^^^^^

:EDIT_MESH:       
  Mesh Edit.

:EDIT_CURVE:      
  Curve Edit.

:EDIT_CURVES:     
  Curves Edit.

:EDIT_SURFACE:    
  Surface Edit.

:EDIT_TEXT:       
  Text Edit.

:EDIT_ARMATURE:   
  Armature Edit.

:EDIT_METABALL:   
  Metaball Edit.

:EDIT_LATTICE:    
  Lattice Edit.

:EDIT_GREASE_PENCIL:
  Grease Pencil Edit.

:EDIT_POINT_CLOUD:
  Point Cloud Edit.

:POSE:            
  Pose.

:SCULPT:          
  Sculpt.

:PAINT_WEIGHT:    
  Weight Paint.

:PAINT_VERTEX:    
  Vertex Paint.

:PAINT_TEXTURE:   
  Texture Paint.

:PARTICLE:        
  Particle.

:OBJECT:          
  Object.

:PAINT_GPENCIL:   
  Grease Pencil Paint.

:EDIT_GPENCIL:    
  Grease Pencil Edit.

:SCULPT_GPENCIL:  
  Grease Pencil Sculpt.

:WEIGHT_GPENCIL:  
  Grease Pencil Weight Paint.

:VERTEX_GPENCIL:  
  Grease Pencil Vertex Paint.

:SCULPT_CURVES:   
  Curves Sculpt.

:PAINT_GREASE_PENCIL:
  Grease Pencil Paint.

.. _rna-enum-context-mode-items:

"""

import typing
