"""


Geometry Component Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:MESH:            
  Mesh.

  Mesh component containing point, corner, edge and face data.

:POINTCLOUD:      
  Point Cloud.

  Point cloud component containing only point data.

:CURVE:           
  Curve.

  Curve component containing spline and control point data.

:INSTANCES:       
  Instances.

  Instances of objects or collections.

.. _rna-enum-geometry-component-type-items:

"""

import typing
