"""


Bake Save Mode Items
^^^^^^^^^^^^^^^^^^^^

:INTERNAL:        
  Internal.

  Save the baking map in an internal image data-block.

:EXTERNAL:        
  External.

  Save the baking map in an external file.

.. _rna-enum-bake-save-mode-items:

"""

import typing
