"""


Attribute Domain Point Face Curve Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:POINT:           
  Point.

  Attribute on point.

:FACE:            
  Face.

  Attribute on mesh faces.

:CURVE:           
  Spline.

  Attribute on spline.

.. _rna-enum-attribute-domain-point-face-curve-items:

"""

import typing
