"""


Brush Gpencil Sculpt Types Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:SMOOTH:          
  Smooth.

  Smooth stroke points.

:THICKNESS:       
  Thickness.

  Adjust thickness of strokes.

:STRENGTH:        
  Strength.

  Adjust color strength of strokes.

:RANDOMIZE:       
  Randomize.

  Introduce jitter/randomness into strokes.

:GRAB:            
  Grab.

  Translate the set of points initially within the brush circle.

:PUSH:            
  Push.

  Move points out of the way, as if combing them.

:TWIST:           
  Twist.

  Rotate points around the midpoint of the brush.

:PINCH:           
  Pinch.

  Pull points towards the midpoint of the brush.

:CLONE:           
  Clone.

  Paste copies of the strokes stored on the internal clipboard.

.. _rna-enum-brush-gpencil-sculpt-types-items:

"""

import typing
