"""


Window Cursor Items
^^^^^^^^^^^^^^^^^^^

:DEFAULT:         
  Default.

:NONE:            
  None.

:WAIT:            
  Wait.

:CROSSHAIR:       
  Crosshair.

:MOVE_X:          
  Move-X.

:MOVE_Y:          
  Move-Y.

:KNIFE:           
  Knife.

:TEXT:            
  Text.

:PAINT_BRUSH:     
  Paint Brush.

:PAINT_CROSS:     
  Paint Cross.

:DOT:             
  Dot Cursor.

:ERASER:          
  Eraser.

:HAND:            
  Hand.

:SCROLL_X:        
  Scroll-X.

:SCROLL_Y:        
  Scroll-Y.

:SCROLL_XY:       
  Scroll-XY.

:EYEDROPPER:      
  Eyedropper.

:PICK_AREA:       
  Pick Area.

:STOP:            
  Stop.

:COPY:            
  Copy.

:CROSS:           
  Cross.

:MUTE:            
  Mute.

:ZOOM_IN:         
  Zoom In.

:ZOOM_OUT:        
  Zoom Out.

.. _rna-enum-window-cursor-items:

"""

import typing
