"""


Clip Editor Mode Items
^^^^^^^^^^^^^^^^^^^^^^

:TRACKING:        
  Tracking.

  Show tracking and solving tools.

:MASK:            
  Mask.

  Show mask editing tools.

.. _rna-enum-clip-editor-mode-items:

"""

import typing
