"""


Rigidbody Object Shape Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:BOX:             
  Box.

  Box-like shapes (i.e. cubes), including planes (i.e. ground planes).

:SPHERE:          
  Sphere.

:CAPSULE:         
  Capsule.

:CYLINDER:        
  Cylinder.

:CONE:            
  Cone.

:CONVEX_HULL:     
  Convex Hull.

  A mesh-like surface encompassing (i.e. shrinkwrap over) all vertices (best results with fewer vertices).

:MESH:            
  Mesh.

  Mesh consisting of triangles only, allowing for more detailed interactions than convex hulls.

:COMPOUND:        
  Compound Parent.

  Combines all of its direct rigid body children into one rigid object.

.. _rna-enum-rigidbody-object-shape-items:

"""

import typing
