"""


Node Float To Int Items
^^^^^^^^^^^^^^^^^^^^^^^

:ROUND:           
  Round.

  Round the float up or down to the nearest integer.

:FLOOR:           
  Floor.

  Round the float down to the next smallest integer.

:CEILING:         
  Ceiling.

  Round the float up to the next largest integer.

:TRUNCATE:        
  Truncate.

  Round the float to the closest integer in the direction of zero (floor if positive; ceiling if negative).

.. _rna-enum-node-float-to-int-items:

"""

import typing
