"""


Brush Gpencil Weight Types Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:WEIGHT:          
  Weight.

  Paint weight in active vertex group.

:BLUR:            
  Blur.

  Blur weight in active vertex group.

:AVERAGE:         
  Average.

  Average weight in active vertex group.

:SMEAR:           
  Smear.

  Smear weight in active vertex group.

.. _rna-enum-brush-gpencil-weight-types-items:

"""

import typing
