"""


Proportional Falloff Curve Only Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:SMOOTH:          
  Smooth.

  Smooth falloff.

:SPHERE:          
  Sphere.

  Spherical falloff.

:ROOT:            
  Root.

  Root falloff.

:INVERSE_SQUARE:  
  Inverse Square.

  Inverse Square falloff.

:SHARP:           
  Sharp.

  Sharp falloff.

:LINEAR:          
  Linear.

  Linear falloff.

.. _rna-enum-proportional-falloff-curve-only-items:

"""

import typing
