"""


Keyframe Paste Offset Value Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:LEFT_KEY:        
  Left Key.

  Paste keys with the first key matching the key left of the cursor.

:RIGHT_KEY:       
  Right Key.

  Paste keys with the last key matching the key right of the cursor.

:CURRENT_FRAME:   
  Current Frame Value.

  Paste keys relative to the value of the curve under the cursor.

:CURSOR_VALUE:    
  Cursor Value.

  Paste keys relative to the Y-Position of the cursor.

:NONE:            
  No Offset.

  Paste keys with the same value as they were copied.

.. _rna-enum-keyframe-paste-offset-value-items:

"""

import typing
