"""


Node Geometry Curve Handle Side Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:LEFT:            
  Left.

  Use the left handles.

:RIGHT:           
  Right.

  Use the right handles.

.. _rna-enum-node-geometry-curve-handle-side-items:

"""

import typing
