"""


Freestyle Module (freestyle)
****************************

This module provides data types of view map components (0D and 1D
elements), base classes for defining line stylization rules
(predicates, functions, chaining iterators, and stroke shaders),
as well as helper functions for style module writing.

"""

from . import utils

from . import types

from . import shaders

from . import predicates

from . import functions

from . import chainingiterators

import typing
