"""


Node Filter Items
^^^^^^^^^^^^^^^^^

:SOFTEN:          
  Soften.

:SHARPEN:         
  Box Sharpen.

  An aggressive sharpening filter.

:SHARPEN_DIAMOND: 
  Diamond Sharpen.

  A moderate sharpening filter.

:LAPLACE:         
  Laplace.

:SOBEL:           
  Sobel.

:PREWITT:         
  Prewitt.

:KIRSCH:          
  Kirsch.

:SHADOW:          
  Shadow.

.. _rna-enum-node-filter-items:

"""

import typing
