"""


Node Map Range Items
^^^^^^^^^^^^^^^^^^^^

:LINEAR:          
  Linear.

  Linear interpolation between From Min and From Max values.

:STEPPED:         
  Stepped Linear.

  Stepped linear interpolation between From Min and From Max values.

:SMOOTHSTEP:      
  Smooth Step.

  Smooth Hermite edge interpolation between From Min and From Max values.

:SMOOTHERSTEP:    
  Smoother Step.

  Smoother Hermite edge interpolation between From Min and From Max values.

.. _rna-enum-node-map-range-items:

"""

import typing
