"""


Uilist Layout Type Items
^^^^^^^^^^^^^^^^^^^^^^^^

:DEFAULT:         
  Default Layout.

  Use the default, multi-rows layout.

:COMPACT:         
  Compact Layout.

  Use the compact, single-row layout.

:GRID:            
  Grid Layout.

  Use the grid-based layout.

.. _rna-enum-uilist-layout-type-items:

"""

import typing
