"""


Node Tree Interface Item Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:SOCKET:          
  Socket.

:PANEL:           
  Panel.

.. _rna-enum-node-tree-interface-item-type-items:

"""

import typing
