"""


Navigation Mode Items
^^^^^^^^^^^^^^^^^^^^^

:WALK:            
  Walk.

  Interactively walk or free navigate around the scene.

:FLY:             
  Fly.

  Use fly dynamics to navigate the scene.

.. _rna-enum-navigation-mode-items:

"""

import typing
