"""


Snap Animation Element Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:FRAME:           
  Frame.

  Snap to frame.

:SECOND:          
  Second.

  Snap to seconds.

:MARKER:          
  Nearest Marker.

  Snap to nearest marker.

.. _rna-enum-snap-animation-element-items:

"""

import typing
