"""


Node Clamp Items
^^^^^^^^^^^^^^^^

:MINMAX:          
  Min Max.

  Constrain value between min and max.

:RANGE:           
  Range.

  Constrain value between min and max, swapping arguments when min > max.

.. _rna-enum-node-clamp-items:

"""

import typing
