"""


Space Image Mode All Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:VIEW:            
  View.

  View the image.

:UV:              
  UV Editor.

  UV edit in mesh editmode.

:PAINT:           
  Paint.

  2D image painting mode.

:MASK:            
  Mask.

  Mask editing.

.. _rna-enum-space-image-mode-all-items:

"""

import typing
