"""


Collection Color Items
^^^^^^^^^^^^^^^^^^^^^^

:NONE:            
  None.

  Assign no color tag to the collection.

:COLOR_01:        
  Color 01.

:COLOR_02:        
  Color 02.

:COLOR_03:        
  Color 03.

:COLOR_04:        
  Color 04.

:COLOR_05:        
  Color 05.

:COLOR_06:        
  Color 06.

:COLOR_07:        
  Color 07.

:COLOR_08:        
  Color 08.

.. _rna-enum-collection-color-items:

"""

import typing
