"""


Linestyle Color Modifier Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:ALONG_STROKE:    
  Along Stroke.

:CREASE_ANGLE:    
  Crease Angle.

:CURVATURE_3D:    
  Curvature 3D.

:DISTANCE_FROM_CAMERA:
  Distance from Camera.

:DISTANCE_FROM_OBJECT:
  Distance from Object.

:MATERIAL:        
  Material.

:NOISE:           
  Noise.

:TANGENT:         
  Tangent.

.. _rna-enum-linestyle-color-modifier-type-items:

"""

import typing
