"""


Nla Mode Blend Items
^^^^^^^^^^^^^^^^^^^^

:REPLACE:         
  Replace.

  The strip values replace the accumulated results by amount specified by influence.

:COMBINE:         
  Combine.

  The strip values are combined with accumulated results by appropriately using addition, multiplication, or quaternion math, based on channel type.

.. _rna-enum-nla-mode-blend-items:

======================================================================

:ADD:             
  Add.

  Weighted result of strip is added to the accumulated results.

:SUBTRACT:        
  Subtract.

  Weighted result of strip is removed from the accumulated results.

:MULTIPLY:        
  Multiply.

  Weighted result of strip is multiplied with the accumulated results.

"""

import typing
