"""


Shrinkwrap Face Cull Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:OFF:             
  Off.

  No culling.

:FRONT:           
  Front.

  No projection when in front of the face.

:BACK:            
  Back.

  No projection when behind the face.

.. _rna-enum-shrinkwrap-face-cull-items:

"""

import typing
