"""


Modifier Shrinkwrap Mode Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:ON_SURFACE:      
  On Surface.

  The point is constrained to the surface of the target object, with distance offset towards the original point location.

:INSIDE:          
  Inside.

  The point is constrained to be inside the target object.

:OUTSIDE:         
  Outside.

  The point is constrained to be outside the target object.

:OUTSIDE_SURFACE: 
  Outside Surface.

  The point is constrained to the surface of the target object, with distance offset always to the outside, towards or away from the original location.

:ABOVE_SURFACE:   
  Above Surface.

  The point is constrained to the surface of the target object, with distance offset applied exactly along the target normal.

.. _rna-enum-modifier-shrinkwrap-mode-items:

"""

import typing
