"""


Keying Flag Items
^^^^^^^^^^^^^^^^^

:INSERTKEY_NEEDED:
  Only Needed.

  Only insert keyframes where they're needed in the relevant F-Curves.

:INSERTKEY_VISUAL:
  Visual Keying.

  Insert keyframes based on 'visual transforms'.

:INSERTKEY_XYZ_TO_RGB:
  XYZ=RGB Colors.

  Color for newly added transformation F-Curves (Location, Rotation, Scale) and also Color is based on the transform axis.

.. _rna-enum-keying-flag-items:

"""

import typing
