"""


Modifier Triangulate Ngon Method Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:BEAUTY:          
  Beauty.

  Arrange the new triangles evenly (slow).

:CLIP:            
  Clip.

  Split the polygons with an ear clipping algorithm.

.. _rna-enum-modifier-triangulate-ngon-method-items:

"""

import typing
