"""


Grease Pencil Selectmode Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:POINT:           
  Point.

  Select only points.

:STROKE:          
  Stroke.

  Select all stroke points.

:SEGMENT:         
  Segment.

  Select all stroke points between other strokes.

.. _rna-enum-grease-pencil-selectmode-items:

"""

import typing
