"""


Region Type Items
^^^^^^^^^^^^^^^^^

:WINDOW:          
  Window.

:HEADER:          
  Header.

:CHANNELS:        
  Channels.

:TEMPORARY:       
  Temporary.

:UI:              
  Sidebar.

:TOOLS:           
  Tools.

:TOOL_PROPS:      
  Tool Properties.

:ASSET_SHELF:     
  Asset Shelf.

:ASSET_SHELF_HEADER:
  Asset Shelf Header.

:PREVIEW:         
  Preview.

:HUD:             
  Floating Region.

:NAVIGATION_BAR:  
  Navigation Bar.

:EXECUTE:         
  Execute Buttons.

:FOOTER:          
  Footer.

:TOOL_HEADER:     
  Tool Header.

:XR:              
  XR.

.. _rna-enum-region-type-items:

"""

import typing
