"""


Rigidbody Object Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^

:ACTIVE:          
  Active.

  Object is directly controlled by simulation results.

:PASSIVE:         
  Passive.

  Object is directly controlled by animation system.

.. _rna-enum-rigidbody-object-type-items:

"""

import typing
