"""


Mapping Type Items
^^^^^^^^^^^^^^^^^^

:POINT:           
  Point.

  Transform a point.

:TEXTURE:         
  Texture.

  Transform a texture by inverse mapping the texture coordinate.

:VECTOR:          
  Vector.

  Transform a direction vector. Location is ignored.

:NORMAL:          
  Normal.

  Transform a unit normal vector. Location is ignored.

.. _rna-enum-mapping-type-items:

"""

import typing
