"""


Views Format Multilayer Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:INDIVIDUAL:      
  Individual.

  Individual files for each view with the prefix as defined by the scene views.

:MULTIVIEW:       
  Multi-View.

  Single file with all the views.

.. _rna-enum-views-format-multilayer-items:

"""

import typing
